Component
=========
.. container:: subclasses

    *Subclasses*

    .. toctree::
       :maxdepth: 1

       Mechanisms <Mechanism>
       Projections <Projection>
       Ports <Port>
       Functions <Functions>
    |

.. container:: related

    *Related*

    .. toctree::
       :maxdepth: 1

       Parameters
       Log
       Registry
       Preferences

.. automodule:: psyneulink.core.components.component
   :members:
   :private-members:
   :exclude-members: Parameters, ComponentLog, COMPONENT_BASE_CLASS, LogLevel, ComponentError, DefaultsFlexibility, ResetMode
